---
permalink: /manual/storage
fbcontact: true
---

# Lagermanagement

Der KMUHelper besitzt ein integriertes Lagermanagement, leider können jedoch nicht mehrere Lager erfasst werden.

Bei jedem Produkt gibt es das Feld "Lagerbestand". Dieses wird bei folgenden Ereignissen aktualisiert:

- Manuelle Änderung
- Lieferung als "eingelagert" markieren
- Bestellung als "versendet" markieren

## Inventar

Wenn Sie Ihren Lagerbestand in den KMUHelper übertragen möchten, geht dies am Besten auf der Seite "Lagerbestand" in der [KMUHelper-App](app.md). (`/kmuhelper/app/#lagerbestand`)

## Zurück

[Zurück zum Handbuch](./README.md)
